#ifndef _I_LM629_H_
#define _I_LM629_H_

//Instructions


//		<Com>	<Code>	<Donnes>	<Commentaire>

//Important : 	Il faut vrifier le busy-bit avant chaque commande ou donne
//Toujours initialiser le Lm  la mise sous tension : initLM()

//Procdure:
// - Check Busybit
// - Envoyer la commande
// - Check Busybit
// - Envoyer l'octet de donne de poids fort
// - Envoyer l'octet de donne de poids faible
// - ...


//Initialisation
#define RESET	0x00	// 0

#define DFH		0x02	// 0		Define Home : dfini la position de rfrence
						// 			Si en mouvement, prit en compte que aprs un STT
						
#define PORT8	0x05	// 0 		dfini la sortie sur 8 bits (face  PORT12 0x06)

//Interruptions
#define LPEI	0x1B	// 16 bits	permet de dfinir la marge d'erreur pour la position
						// 			lorsque la postion sort de ces marges, l'interruption
						//			correspondante est active (status : bit 5)
#define LPES	0x1A	// 16 bits	mme chse que LPEI, arrte le moteur en plus

#define RSTI	0x1D	// 16 bits	Reset des bits d'interruption, 1 ou plusieurs en mme temps
						//			les bits utiliss correspondent  ceux de RDSTAT
						//			pour chaque bit  0 de 1  6, l'interruption correspondante
						//			subit un reset. Donc, pour tous : 0x0000

//Contrle du filtre
#define LFIL	0x1E	// 16 bits	charge les paramtres du filtre, dans le buffer

						//			bit 15-8	-> Intervalle de drivation
						//			bit 7-4		-> Non utilis
						// 			bit 3		-> kp (coef proportionnel)
						// 			bit 2 		-> ki (coef intgral)
						// 			bit 1		-> kd (coef driv)
						// 			bit 0		-> il (integral limit)
						
						//			Pour chaque bit 3-0, positionn, on envoie ensuite
						//			la donne correspondante, dans l'ordre 3-0.
						
#define UDF		0x04	// 0 		met effectivement  jour les paramtres du filtre (aprs LFIL)

//Contrle de la trajectoire
#define LTRJ	0x1F	// 16 bits	charge les paramtres de la trajectoire, dans le buffer

						//			bit 15-13	-> Non utilis
						//			bit 12		-> Sens de rotation (asservissement en vitesse uniquement)
						//			bit 11		-> Asservissement en mode vitesse (sinon position)
						//			bit 10		-> Ralentir normalement (trajectoire)
						//			bit 9		-> Freinage max
						//			bit 8		-> Envoyer 0 au moteur
						//			bit 7-6		-> Non utilis
						//			bit 5		-> On va charger l'acclration ( l'arret)
						//			bit 4		-> Acclration relative
						//			bit 3		-> On va charger la vitesse
						//			bit 2		-> Vitesse relative
						//			bit 1		-> On va charger la position
						//			bit 0		-> Position relative
						
						//			Pour chaque bit 5,3,1 positionn, on envoie ensuite les donnes
						//			dans cet ordre. Chaque donne fait 32 bits,  envoyer en 2 fois.
						//			Les 2 octets de poids fort sont envoys, puis les 2 octets de
						//			poids faible.

#define LTRJ_HAND_BRAKE 0x0200	//Freinage max

#define LTRJ_BIT_ACCEL	0x0020
#define LTRJ_BIT_VIT	0x000A
#define LTRJ_BIT_POS	0x0002

#define STT		0x01	// 0		Valide les modifications et dmarre le moteur
						//			peut tre fait en marche, si l'acclration n'a pas t change

//Lecture d'informations
#define RDSTAT	aucun	// 8 bits	Pas de code, il faut mettre /CS /PS /RD  0
						//			Bits 6-1 remis  0 par RSTI
//Status Byte
typedef struct {
	unsigned	busy:		1;	//0	A 1 si le LM est occup
	unsigned	cmd_err:	1;	//1 Erreur de commande (lecture  la place d'criture et inversement
	unsigned	trj_end:	1;	//2	Trajectoire termine
	unsigned	idx_pos:	1;	//3	A 1 si on a modifi l'index de position
	unsigned	dep_esp:	1;	//4	Dpassement d'espace pour la position
	unsigned	pos_err:	1;	//5	Erreur de position excessive (par rapport auc limites fixes)
	unsigned	pt_arr:		1;	//6	Point d'arret atteint
	unsigned	motor_off:	1;	//7	Moteur teint
} s_g_data;


//dernire donne lue
int8 g_data1;
int8 g_data2;

//Valeurs l'octet STATUS

#define STATUS_BUSY			0x01 //	A 1 si le LM est occup                                         
#define STATUS_CMDERR		0x02 //	Erreur de commande (lecture  la place d'criture et inversement
#define STATUS_TRJ_END		0x04 //	Trajectoire termine                                            
#define STATUS_IDX_POS		0x08 //	A 1 si on a modifi l'index de position                         
#define STATUS_DEP_ESP		0x10 //	Dpassement d'espace pour la position                           
#define STATUS_POS_ERR		0x20 //	Erreur de position excessive (par rapport aux limites fixes)   
#define STATUS_PT_ARR		0x40 //	Point d'arret atteint                                           
#define STATUS_MOTOR_OFF	0x80 //	Moteur teint                                                   

#define STATUS_ERRORS		0x30 //STATUS_DEP_ESP | STATUS_POS_ERR


#define RDSIGS	0x0C	// 16 bits
						//			bit 15	-> interruption active
						//			bit 14	-> acclration charge (mais pas appliqu)
						//			bit 13	-> filtre charg (mais pas encore appliqu)
						//			bit 12	-> avance vers l'avant (en asservissement de vitesse)
						//			bit 11	-> mode asservissement de vitesse
						//			bit 10	-> trajectoire entirement cre (effac par le STT suivant)
						//			bit 9	-> LPES activ
						//			bit 8	-> Mode 8 bit
						//			bit 7-1	-> voir RDSTAT
						//			bit 0	-> A 1 si SIP a t excute

//Entres / sorties sur le port des donnes

void output_data(int8 data);

#inline
int8 input_data();

void initLM();

#separate
void readStatus1();
#separate
void readStatus2();

#separate
void execCmd1(unsigned int8 cmd);
#separate
void execCmd2(unsigned int8 cmd);

#separate
void sendData1(unsigned int16 data);
#separate
void sendData2(unsigned int16 data);

#separate
void execCmd(unsigned char cmd);

#separate
void chkBusy1();
#separate
void chkBusy2();

#separate
int16 readData1();
#separate
int16 readData2();

void regler_Proportionnel(int8 data);
void regler_Integral(int8 data);
void regler_Derivee(int8 data);
void regler_intlimit(int8 data);

#endif //_I_LM629_H_
